#
# spec file for package python-libevdev
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%global modname libevdev
%define libevdev_reqver 1.6.0
Name:           python-%{modname}
Version:        0.12
Release:        1.1
Summary:        Python wrapper around the libevdev C library
License:        MIT
Group:          Development/Libraries/Python
URL:            https://python-libevdev.readthedocs.io/
Source0:        https://files.pythonhosted.org/packages/source/l/libevdev/libevdev-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  libevdev-devel >= %{libevdev_reqver}
BuildRequires:  python-rpm-macros
%define libmodule %(rpm -q --qf "%%{name}" -f $(readlink -f %{_prefix}/lib*/libevdev.so))
Requires:       %{libmodule} >= %{libevdev_reqver}
BuildArch:      noarch
%python_subpackages

%description
python-libevdev is a wrapper around the libevdev C library, with a
pythonic API.

%prep
%autosetup -p1 -n %{modname}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
cd test
%pytest

%files %{python_files}
%license COPYING
%doc README.md
%{python_sitelib}/libevdev
%{python_sitelib}/libevdev-%{version}.dist-info

%changelog
* Tue Jun  3 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.12
  * doc: add a readthedocs config file
  * docs: install the rtd sphinx theme for readthedocs
  * readthedocs: fix path to requirements.txt
  * setup.cfg: Replace dashes with underscores
  * CI: add required workflow rules
  * Fix intersphinx mapping
- Limit Python files matched in %%files section
- Switch package to modern Python Stack on SLE-15
  * Use Python 3.11 on SLE-15 by default
  * Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  * Add python-pip and python-wheel to BuildRequires
  * Replace %%python_build with %%pyproject_wheel
  * Replace %%python_install with %%pyproject_install
* Mon Jan  6 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Avoid usage of %%{_libdir}: a noarch package cannot rely on libdir
  pointing to arch-specific packages. TWeak using
  %%{_prefix}/lib*/libevdev.so to find the correct library package
  %%name.
* Sat Sep 24 2022 Dirk Müller <dmueller@suse.com>
- upadte to 0.11:
  * doc updates
  * fix broken link
- use pypi tarballs
* Mon Nov 22 2021 Matej Cepl <mcepl@suse.com>
- BuildRequires on a binary library package is a bad idea as well
  as the required SOVER needs to be calculated.
* Fri Nov 19 2021 Callum Farmer <gmbr3@opensuse.org>
- initial packaging required by libwacom (bsc#1192852)
